# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added 
- Created CHANGELOG
- New features with infix operators

### Changes
- Links in pyproject.toml updated to new repo name
- new README.md

## [0.2.0] - 2023-02-01

## Fixed
- First verion to actually work as advertised

## [0.1.0] - 2023-01-31

### Added

- Initial test deployment
- note: was broken